# NovaCodon Gencalc

'gencalc' is a Python library for calculating the start and end year of any generation, by Niral Bhatt.

## Installation

To install, simply add the library to your Python project.

```bash
pip install gencalc